==> mobroute-0.5.0.tar.gz: mobroute-v0.5.0/dbquery_test/loadconnections_test.go <==
package dbquery_test

import (
	"os"
	"reflect"
	"testing"

	"git.sr.ht/~mil/mobroute/dbquery"
	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/testhelper/dbquerytesthelper"
)

func Test_LoadConnections(t *testing.T) {
	testCases := []struct {
		Test        string
		MockGTFS    map[int]string
		Sources     []int
		Date        uint
		TimeRange   [2]int
		ExpectConns []dbt.Connection
	}{
		{
			Test:     "Handles a singleday query ok",
			MockGTFS: map[int]string{42: "../testhelper/mockgtfs/gtfs_sample_0.yml"},
			Sources:  []int{42},
			Date:     20240304,
			TimeRange: [2]int{
				UTCify(t, 20240304, "America/New_York", 60*60*12), UTCify(t, 20240304, "America/New_York", 60*60*13),
			},
			ExpectConns: []dbt.Connection{
				// ConnID, TripID, FromST, FromSeq, FromSSIDU, ToSSIDU, ToStopSequence, ToST
				{"42_trip_foo_up_wk_1", "trip_foo_up_wk", 25560, "1", "42_101", "42_102", "2", 25621},
				{"42_trip_foo_up_wk_2", "trip_foo_up_wk", 25621, "2", "42_102", "42_103", "3", 25681},
			},
		},
		{
			Test:     "Handles a multiday query (crossing boundry of 24hrs, interleaving) ok",
			MockGTFS: map[int]string{42: "../testhelper/mockgtfs/gtfs_sample_0.yml"},
			Sources:  []int{42},
			Date:     20230818,
			TimeRange: [2]int{
				UTCify(t, 20240818, "America/New_York", 60*60*24), UTCify(t, 20240818, "America/New_York", 60*60*25),
			},
			ExpectConns: []dbt.Connection{
				// ConnID, TripID, FromST, FromSeq, FromSSIDU, ToSSIDU, ToStopSequence, ToST
				{"42_trip_bar_up_daystart_1", "trip_bar_up_daystart", 72060, "1", "42_101", "42_102", "2", 72121},
				{"42_trip_foo_up_dayend_1", "trip_foo_up_dayend", 72061, "1", "42_101", "42_102", "2", 72122},
				{"42_trip_bar_up_daystart_2", "trip_bar_up_daystart", 72121, "2", "42_102", "42_103", "3", 72181},
				{"42_trip_foo_up_dayend_2", "trip_foo_up_dayend", 72122, "2", "42_102", "42_103", "3", 72241},
			},
		},
		{
			Test: "Support different timezones from different sources (normalizing to UTC time)",
			MockGTFS: map[int]string{
				// Note gtfs_sample_{0,1}.yml have the exact same schedules
				// but the timezone set in agency.txt is different
				42: "../testhelper/mockgtfs/gtfs_sample_0.yml",
				43: "../testhelper/mockgtfs/gtfs_sample_1.yml",
			},
			Sources: []int{42, 43},
			Date:    20240304,
			TimeRange: [2]int{
				UTCify(t, 20240304, "America/New_York", 60*60*10), UTCify(t, 20240304, "America/New_York", 60*60*14),
			},
			ExpectConns: []dbt.Connection{
				// ConnID, TripID, FromST, FromSeq, FromSSIDU, ToSSIDU, ToStopSequence, ToST
				{"43_trip_foo_up_wk_1", "trip_foo_up_wk", 21960, "1", "43_101", "43_102", "2", 22021},
				{"43_trip_foo_up_wk_2", "trip_foo_up_wk", 22021, "2", "43_102", "43_103", "3", 22081},
				{"42_trip_foo_up_wk_1", "trip_foo_up_wk", 25560, "1", "42_101", "42_102", "2", 25621},
				{"42_trip_foo_up_wk_2", "trip_foo_up_wk", 25621, "2", "42_102", "42_103", "3", 25681},
			},
		},
	}

	for _, testCase := range testCases {
		if sqlxDB, dbPath, err := dbquerytesthelper.PrepareMockLoadComputeAndOpenDB(
			testCase.MockGTFS,
		); err != nil {
			t.Fatalf("Error preparing testcase: %v", err)
		} else if conns, err := dbquery.LoadConnections(
			sqlxDB, testCase.Sources, testCase.Date, testCase.TimeRange[0], testCase.TimeRange[1],
		); err != nil {
			t.Fatalf("Error: %v: DB: %s", err, dbPath)
		} else if !reflect.DeepEqual(testCase.ExpectConns, *conns) {
			t.Fatalf(
				"LoadConnections Test failed: %s - expected: %v; got: %v; DB: (%s)",
				testCase.Test,
				testCase.ExpectConns,
				*conns,
				dbPath,
			)
		} else {
			os.Remove(dbPath)
		}
	}
}

==> mobroute-0.8.4.tar.gz: mobroute-v0.8.4/dbquery_test/loadconnections_test.go <==
package dbquery_test

import (
	"os"
	"reflect"
	"testing"

	"git.sr.ht/~mil/mobroute/dbquery"
	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/testhelper/dbquerytesthelper"
)

func Test_LoadConnections(t *testing.T) {
	testCases := []struct {
		Test                string
		MockGTFS            map[int]string
		TimezoneToUTCOffset map[string]int
		FeedIDs             []int
		Date                uint
		TimeRange           [2]int
		ExpectConns         []dbt.Connection
	}{
		{
			Test:                "Handles a singleday query ok",
			MockGTFS:            map[int]string{42: "../testhelper/mockgtfs/gtfs_sample_0.yml"},
			TimezoneToUTCOffset: map[string]int{"America/New_York": UTCify(t, 20240304, "America/New_York", 0)},
			FeedIDs:             []int{42},
			Date:                20240304,
			TimeRange: [2]int{
				UTCify(t, 20240304, "America/New_York", 60*60*12), UTCify(t, 20240304, "America/New_York", 60*60*13),
			},
			ExpectConns: []dbt.Connection{
				// ConnID, TripID, FromST, FromSeq, FromSSIDU, ToSSIDU, ToStopSequence, ToST
				{"42_trip_foo_up_wk_1", "trip_foo_up_wk", 25560, "1", "42_101", "42_102", "2", 25621},
				{"42_trip_foo_up_wk_2", "trip_foo_up_wk", 25621, "2", "42_102", "42_103", "3", 25681},
			},
		},
		{
			Test:                "Handles a multiday query (crossing boundry of 24hrs, interleaving) ok",
			MockGTFS:            map[int]string{42: "../testhelper/mockgtfs/gtfs_sample_0.yml"},
			TimezoneToUTCOffset: map[string]int{"America/New_York": UTCify(t, 20240818, "America/New_York", 0)},
			FeedIDs:             []int{42},
			Date:                20230818,
			TimeRange: [2]int{
				UTCify(t, 20240818, "America/New_York", 60*60*24), UTCify(t, 20240818, "America/New_York", 60*60*25),
			},
			ExpectConns: []dbt.Connection{
				// ConnID, TripID, FromST, FromSeq, FromSSIDU, ToSSIDU, ToStopSequence, ToST
				{"42_trip_bar_up_daystart_1", "trip_bar_up_daystart", 72060, "1", "42_101", "42_102", "2", 72121},
				{"42_trip_foo_up_dayend_1", "trip_foo_up_dayend", 72061, "1", "42_101", "42_102", "2", 72122},
				{"42_trip_bar_up_daystart_2", "trip_bar_up_daystart", 72121, "2", "42_102", "42_103", "3", 72181},
				{"42_trip_foo_up_dayend_2", "trip_foo_up_dayend", 72122, "2", "42_102", "42_103", "3", 72241},
			},
		},
		{
			Test: "Support different timezones from different feeds (normalizing to UTC time)",
			MockGTFS: map[int]string{
				// Note gtfs_sample_{0,1}.yml have the exact same schedules
				// but the timezone set in agency.txt is different
				42: "../testhelper/mockgtfs/gtfs_sample_0.yml",
				43: "../testhelper/mockgtfs/gtfs_sample_1.yml",
			},
			TimezoneToUTCOffset: map[string]int{
				"America/New_York": UTCify(t, 20240304, "America/New_York", 0),
				"America/Chicago":  UTCify(t, 20240304, "America/Chicago", 0),
			},
			FeedIDs: []int{42, 43},
			Date:    20240304,
			TimeRange: [2]int{
				UTCify(t, 20240304, "America/New_York", 60*60*10), UTCify(t, 20240304, "America/New_York", 60*60*14),
			},
			ExpectConns: []dbt.Connection{
				// ConnID, TripID, FromST, FromSeq, FromSSIDU, ToSSIDU, ToStopSequence, ToST
				{"43_trip_foo_up_wk_1", "trip_foo_up_wk", 21960, "1", "43_101", "43_102", "2", 22021},
				{"43_trip_foo_up_wk_2", "trip_foo_up_wk", 22021, "2", "43_102", "43_103", "3", 22081},
				{"42_trip_foo_up_wk_1", "trip_foo_up_wk", 25560, "1", "42_101", "42_102", "2", 25621},
				{"42_trip_foo_up_wk_2", "trip_foo_up_wk", 25621, "2", "42_102", "42_103", "3", 25681},
			},
		},
	}

	for _, testCase := range testCases {
		if sqlxDB, dbPath, err := dbquerytesthelper.PrepareMockLoadComputeAndOpenDB(
			testCase.MockGTFS,
		); err != nil {
			t.Fatalf("Error preparing testcase: %v", err)
		} else if conns, err := dbquery.LoadConnections(
			sqlxDB, testCase.FeedIDs, testCase.TimezoneToUTCOffset,
			testCase.Date, testCase.TimeRange[0], testCase.TimeRange[1],
		); err != nil {
			t.Fatalf("Error: %v: DB: %s", err, dbPath)
		} else if !reflect.DeepEqual(testCase.ExpectConns, *conns) {
			t.Fatalf(
				"LoadConnections Test failed: %s - expected: %v; got: %v; DB: (%s)",
				testCase.Test,
				testCase.ExpectConns,
				*conns,
				dbPath,
			)
		} else {
			os.Remove(dbPath)
		}
	}
}
